@@ -18,9 +18,11 @@ perl -MDevel::Cover t/08_connection.t
 perl -MDevel::Cover t/09_message.t
 perl -MDevel::Cover t/10_producer.t
 perl -MDevel::Cover t/11_consumer.t
-perl -MDevel::Cover t/70_kafka_usage.t
-perl -MDevel::Cover t/71_kafka_bench.t
-perl -MDevel::Cover t/89_cluster_stop.t
+perl -MDevel::Cover t/20_kafka_usage.t
+perl -MDevel::Cover t/21_kafka_bench.t
+perl -MDevel::Cover t/30_cluster_stop.t
+perl -MDevel::Cover t/40_autocreate_topics.t
+perl -MDevel::Cover t/41_fork.t
 perl -MDevel::Cover t/90_mock_io.t
 perl -MDevel::Cover t/91_mock_usage.t
 perl -MDevel::Cover t/92_mock_bench.t
